package
Version:
v0.0.0-...-657a6a2
Opens a new window with list of versions in this module.
Published: Feb 2, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Gender - gender
const (
GenderMale Gender = iota + 1
GenderFemale
GenderCustom
)
type User struct {
ID string `json:"id"`
Age int `json:"age"`
Name string `json:"name"`
Gender Gender `json:"gender"`
}
User - user
Source Files
¶
Click to show internal directories.
Click to hide internal directories.